<?php
include_once 'Config.php';

class Util
{
	public static function formatProse($buffer, $specialFirst=true) {
		// split by newline characters
		$p = preg_split("/\n.?\n/", $buffer);
		
		$paragraphs = array();
		$i = 0;
		
		// make sure all of our paragraphs contain more than just whitespace
		foreach($p as $pc) {
			if(!preg_match('/^\s*$/', $pc)) {
				$paragraphs[$i++] = $pc;
			}
		}
		
		// clear buffer
		$buffer = '';
		
		// format first paragraph
		if($specialFirst) {
			$buffer .= "<p class=\"content-start\">".$paragraphs[0]."</p>\n";
		}
		
		// format remaining paragraphs and add them to buffer
		for($i = 1; $i < count($paragraphs); $i++) {
			$buffer .= "<p>".$paragraphs[$i]."</p>\n";
		}
		
		return $buffer;
	}
	
	public static function formatBox($title, $content, $heading='')
	{
		$buffer = '';
		$buffer .= "<div class=\"box-title\">$title</div>\n";
		$buffer .= "<div class=\"box-content\">\n";
		if(!empty($heading)) {
			$buffer .= "<span class=\"box-heading\">$heading</span>\n";
		}
		$buffer .= self::formatProse($content, false);
		$buffer .= "</div>\n";
		
		return $buffer;
	}
	
	public static function makeLink($args)
	{
		$root = Config::getProperty('webroot');
		$buffer = '';
		$display = '';
		$img = array();
		$suffix = '';
		
		if(Config::getProperty('current language') != Config::getProperty('default language')) {
			$suffix = '/lang/'.Config::getProperty('current language');
		}
		
		$buffer .= '<a';
		
		foreach($args as $name=>$value) {
			if($name == 'href' && $value != 'self') {
				$value = $root.'request/'.$value.$suffix;
			} elseif($value == 'self') {
				$value = $root.'request/'.Config::getProperty('current id').$suffix;
			}
			
			if($name == 'display') {
				$display = $value;
			} elseif(substr($name, 0, 3) == 'img') {
				$img[substr($name,3,strlen($name)-3)] = $value;
			} else {
				$buffer .= " $name=\"$value\"";
			}
		}
		
		if(!empty($img)) {
			$display = self::makeImage($img);
		}
		
		if(empty($display)) {
			$display = $args['href'];
		}
		
		$buffer .= ">$display</a>";
		
		return $buffer;
	}
	
	public static function makeImage($args)
	{
		$params = array();
		$buffer = '';
		$root = Config::getProperty('webroot');
		
		$buffer .= "<img";
		
		foreach($args as $name=>$value) {
			if($name == 'src') {
				$value = $root.$value;
			}
			$buffer .= " $name=\"$value\"";
		}
		
		$buffer .= " />";
		
		return $buffer;
	}
	
	public static function makeStyle($args)
	{
		$params = array();
		$buffer = '';
		$root = Config::getProperty('webroot');
		
		$buffer .= "<link";
		
		foreach($args as $name=>$value) {
			if($name == 'href') {
				$value = $root.'templates/styles/'.$value;
			}
			$buffer .= " $name=\"$value\"";
		}
		
		$buffer .= " />";
		
		return $buffer;
	}
	
	public static function makeWebPath($args)
	{
		$root = Config::getProperty('webroot');
		
		return $root.$args['path'];
	}
}


function lprint($text)
{
	print $text."\n";
}

function fprint($text, $class)
{
	lprint(fstring($text, $class));
}

function fstring($text, $class)
{
	 return "<span class=\"$class\">$text</span>";
}
?>
